==> kadaster-gds2-1.2-sources.jar: nl/kadaster/schemas/gds2/afgifte_bestandophalen/v20120901/ObjectFactory.java <==

package nl.kadaster.schemas.gds2.afgifte_bestandophalen.v20120901;

import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlElementDecl;
import javax.xml.bind.annotation.XmlRegistry;
import javax.xml.namespace.QName;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the nl.kadaster.schemas.gds2.afgifte_bestandophalen.v20120901 package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {

    private final static QName _BestandOphalen_QNAME = new QName("http://www.kadaster.nl/schemas/gds2/afgifte-bestandophalen/v20120901", "BestandOphalen");

    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: nl.kadaster.schemas.gds2.afgifte_bestandophalen.v20120901
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link BestandOphalenType }
     * 
     */
    public BestandOphalenType createBestandOphalenType() {
        return new BestandOphalenType();
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link BestandOphalenType }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://www.kadaster.nl/schemas/gds2/afgifte-bestandophalen/v20120901", name = "BestandOphalen")
    public JAXBElement<BestandOphalenType> createBestandOphalen(BestandOphalenType value) {
        return new JAXBElement<BestandOphalenType>(_BestandOphalen_QNAME, BestandOphalenType.class, null, value);
    }

}

==> kadaster-gds2-2.3-sources.jar: nl/kadaster/schemas/gds2/afgifte_bestandophalen/v20120901/ObjectFactory.java <==

package nl.kadaster.schemas.gds2.afgifte_bestandophalen.v20120901;

import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlElementDecl;
import javax.xml.bind.annotation.XmlRegistry;
import javax.xml.namespace.QName;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the nl.kadaster.schemas.gds2.afgifte_bestandophalen.v20120901 package. 
 * &lt;p&gt;An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {

    private final static QName _BestandOphalen_QNAME = new QName("http://www.kadaster.nl/schemas/gds2/afgifte-bestandophalen/v20120901", "BestandOphalen");

    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: nl.kadaster.schemas.gds2.afgifte_bestandophalen.v20120901
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link BestandOphalenType }
     * 
     */
    public BestandOphalenType createBestandOphalenType() {
        return new BestandOphalenType();
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link BestandOphalenType }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link BestandOphalenType }{@code >}
     */
    @XmlElementDecl(namespace = "http://www.kadaster.nl/schemas/gds2/afgifte-bestandophalen/v20120901", name = "BestandOphalen")
    public JAXBElement<BestandOphalenType> createBestandOphalen(BestandOphalenType value) {
        return new JAXBElement<BestandOphalenType>(_BestandOphalen_QNAME, BestandOphalenType.class, null, value);
    }

}
